@@ -3,7 +3,7 @@
 from typing import List
 
 # Local Modules
-from app.kb.entity.types import Qualifier, Snak
+from cofactr.kb.entity.types import Qualifier, Snak
 
 
 def qualifier(
